@@ -9,6 +9,8 @@ UserSettings::UserSettings()
     setUsername("");
     setPassword("");
     setScreensaverIsInhibited(false);
+    setLargeAlbumIcons(false);
+    setAlbumIcons(false);
 }
 
 
@@ -49,6 +51,17 @@ bool UserSettings::setScreensaverIsInhibited(bool newScreensaverInhibited)
     return(newScreensaverInhibited);
 }
 
+bool UserSettings::setLargeAlbumIcons(bool newLargeAlbumIcons)
+{
+    largeAlbumIcons_i = newLargeAlbumIcons;
+    return(newLargeAlbumIcons);
+}
+
+bool UserSettings::setAlbumIcons(bool newAlbumIcons)
+{
+    albumIcons_i = newAlbumIcons;
+    return(newAlbumIcons);
+}
 
 //bool UserSettings::load()
 //{
@@ -166,6 +179,8 @@ bool UserSettings::clone (const UserSettings &other)
     username_i=other.username();
     password_i=other.password();
     screensaverIsInhibited_i=other.screensaverIsInhibited();
+    largeAlbumIcons_i=other.largeAlbumIcons();
+    albumIcons_i=other.albumIcons();
 return(true);
 }
 
